# Licensed under a 3-clause BSD style license - see LICENSE.rst

"""
SOLARSYSTEM.IMCCE.SKYBOT
------------------------

:author: Michael Mommert (mommermiscience@gmail.com)
"""

from ....imcce import Skybot, SkybotClass


__all__ = ["Skybot", "SkybotClass"]
